summaryrefslogtreecommitdiff
path: root/distrib/pc532/floppies/inst/install.sh
diff options
context:
space:
mode:
Diffstat (limited to 'distrib/pc532/floppies/inst/install.sh')
-rw-r--r--distrib/pc532/floppies/inst/install.sh31
1 files changed, 16 insertions, 15 deletions
diff --git a/distrib/pc532/floppies/inst/install.sh b/distrib/pc532/floppies/inst/install.sh
index 83fc6fbc02d..5b43b3b4e5e 100644
--- a/distrib/pc532/floppies/inst/install.sh
+++ b/distrib/pc532/floppies/inst/install.sh
@@ -1,5 +1,4 @@
#!/bin/sh
-# $OpenBSD: install.sh,v 1.5 1996/06/29 05:54:20 tholo Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -27,8 +26,10 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# OpenBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -46,9 +47,9 @@ getresp() {
fi
}
-echo "Welcome to the OpenBSD ${VERSION} installation program."
+echo "Welcome to the NetBSD ${VERSION} installation program."
echo ""
-echo "This program is designed to help you put OpenBSD on your hard disk,"
+echo "This program is designed to help you put NetBSD on your hard disk,"
echo "in a simple and rational way. You'll be asked several questions,"
echo "and it would probably be useful to have your disk's hardware"
echo "manual, the installation notes, and a calculator handy."
@@ -132,7 +133,7 @@ labelname=$resp
echo ""
echo "You will now need to provide some information about your disk's"
echo "geometry. This should either be in the User's Manual for your disk,"
-echo "or you should have written down what OpenBSD printed when booting."
+echo "or you should have written down what NetBSD printed when booting."
echo "(Note that he geometry that's printed at boot time is preferred.)"
echo ""
echo -n "Number of bytes per disk sector? [512] "
@@ -229,7 +230,7 @@ echo ""
swap=0
while [ $swap -eq 0 ]; do
- echo "$units_left $sizeunit remaining in OpenBSD portion of disk."
+ echo "$units_left $sizeunit remaining in NetBSD portion of disk."
echo -n "Swap partition size (in $sizeunit)? "
getresp
case $resp in
@@ -250,7 +251,7 @@ echo ""
boot=0
while [ $boot -eq 0 ]; do
- echo "$units_left $sizeunit remaining in OpenBSD portion of disk."
+ echo "$units_left $sizeunit remaining in NetBSD portion of disk."
echo -n "Boot partition size (in $sizeunit)? "
getresp
case $resp in
@@ -273,7 +274,7 @@ blocksize=8192
$DONTDOIT mount -u /dev/rd0 /
cat /etc/disktab.preinstall > $DT
echo "" >> $DT
-echo "$labelname|OpenBSD installation generated:\\" >> $DT
+echo "$labelname|NetBSD installation generated:\\" >> $DT
echo " :dt=${type}:ty=winchester:\\" >> $DT
echo -n " :nc#${cyls_per_disk}:ns#${sects_per_track}" >> $DT
echo ":nt#${tracks_per_cyl}:\\" >> $DT
@@ -293,8 +294,8 @@ _offset=`expr $boot_offset \* $sizemult`
echo " :ph#${_size}:oh#${_offset}:th=boot:\\" >> $DT
echo "You will now have to enter information about any other partitions"
-echo "to be created in the OpenBSD portion of the disk. This process will"
-echo "be complete when you've filled up all remaining space in the OpenBSD"
+echo "to be created in the NetBSD portion of the disk. This process will"
+echo "be complete when you've filled up all remaining space in the NetBSD"
echo "portion of the disk."
while [ $part_used -lt $partition ]; do
@@ -302,7 +303,7 @@ while [ $part_used -lt $partition ]; do
units_left=`expr $partition - $part_used`
while [ $part_size -eq 0 ]; do
echo ""
- echo -n "$units_left $sizeunit remaining in OpenBSD portion of "
+ echo -n "$units_left $sizeunit remaining in NetBSD portion of "
echo "the disk"
echo -n "Next partition size (in $sizeunit)? "
getresp
@@ -362,7 +363,7 @@ sync
echo ""
echo "THIS IS YOUR LAST CHANCE!!!"
echo ""
-echo -n "Are you SURE you want OpenBSD installed on your hard drive? (yes/no) "
+echo -n "Are you SURE you want NetBSD installed on your hard drive? (yes/no) "
answer=""
while [ "$answer" = "" ]; do
getresp
@@ -432,9 +433,9 @@ fi
echo ""
echo "Populating filesystems with bootstrapping binaries and config files"
-$DONTDOIT tar -cfX - . | (cd /mnt ; tar -xpf - )
+$DONTDOIT tar --one-file-system -cf - . | (cd /mnt ; tar --unlink -xpf - )
$DONTDOIT cp /tmp/.hdprofile /mnt/.profile
-$DONTDOIT gzip -d /mnt/bsd.gz
+$DONTDOIT gzip -d /mnt/netbsd.gz
echo ""
echo -n "Creating an fstab..."
@@ -464,7 +465,7 @@ echo "You can now boot off the hard drive."
echo ""
echo "The remaining tasks are:"
echo ""
-echo "To load and install the OpenBSD distribution sets."
+echo "To load and install the NetBSD distribution sets."
echo "Currently the hard drive's root filesystem is mounted on /mnt"
echo ""
echo "Consult the installation notes which will describe how to"
@@ -27,8 +26,10 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#
+# $Id: install.sh,v 1.6 1996/09/05 21:26:48 deraadt Exp $
-# OpenBSD installation script.
+# NetBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.